/*
	Copyright  1995-2001, The AROS Development Team. All rights reserved.
	$Id: misc.c,v 1.3 2007/04/17 14:53:26 tokai Exp $
 
	Desc:
	Lang: English
*/

/*********************************************************************************************/

#include <intuition/intuition.h>
#include <libraries/asl.h>
#include <libraries/gadtools.h>
#include <proto/exec.h>
#include <proto/dos.h>
#include <proto/intuition.h>
#include <proto/gadtools.h>
#include <proto/asl.h>

#define CATCOMP_NUMBERS
#include "more_strings.h"

#include "global.h"
#include "more_version.h"

#include <string.h>

/*********************************************************************************************/

struct Library *AslBase;

/*********************************************************************************************/

static struct NewMenu nm[] =
	{
		{NM_TITLE, (STRPTR)MSG_MEN_PROJECT    },
			{NM_ITEM, (STRPTR)MSG_MEN_PROJECT_OPEN          },
#if 0
			{NM_ITEM, NM_BARLABEL                           },
			{NM_ITEM, (STRPTR)MSG_MEN_PROJECT_PRINT         },
#endif
			{NM_ITEM, NM_BARLABEL                           },
			{NM_ITEM, (STRPTR)MSG_MEN_PROJECT_ABOUT         },
			{NM_ITEM, NM_BARLABEL                           },
			{NM_ITEM, (STRPTR)MSG_MEN_PROJECT_QUIT          },
		{NM_TITLE, (STRPTR)MSG_MEN_NAVIGATION },
			{NM_ITEM, (STRPTR)MSG_MEN_NAVIGATION_FIND       },
			{NM_ITEM, (STRPTR)MSG_MEN_NAVIGATION_FIND_NEXT  },
			{NM_ITEM, (STRPTR)MSG_MEN_NAVIGATION_FIND_PREV  },
			{NM_ITEM, NM_BARLABEL                           },
			{NM_ITEM, (STRPTR)MSG_MEN_NAVIGATION_JUMP       },
		{NM_END}
	};

/*********************************************************************************************/

void InitMenus(void)
{
	struct NewMenu *actnm = nm;

	for(actnm = nm; actnm->nm_Type != NM_END; actnm++)
	{
		if (actnm->nm_Label != NM_BARLABEL)
		{
			ULONG  id = (ULONG)actnm->nm_Label;
			STRPTR str = MSG(id);

			if (actnm->nm_Type == NM_TITLE)
			{
				actnm->nm_Label = str;
			}
			else
			{
				actnm->nm_Label = str + 2;
				if (str[0] != ' ') actnm->nm_CommKey = str;
			}
			actnm->nm_UserData = (APTR)id;

		} /* if (actnm->nm_Label != NM_BARLABEL) */

	} /* for(actnm = nm; nm->nm_Type != NM_END; nm++) */

}

/*********************************************************************************************/

void MakeMenus(void)
{
	menus = CreateMenusA(nm, NULL);
	if (!menus) Cleanup(MSG(MSG_CANT_CREATE_MENUS));

	if (!LayoutMenusA(menus, vi, NULL)) Cleanup(MSG(MSG_CANT_CREATE_MENUS));

}

/*********************************************************************************************/

void KillMenus(void)
{
	if (win) ClearMenuStrip(win);
	if (menus) FreeMenus(menus);

	menus = NULL;
}

/*********************************************************************************************/
static UBYTE	 filebuffer[MAXPATH];

STRPTR GetFileFromLock(BPTR l)
{
	if (NameFromLock(l, filebuffer, sizeof(filebuffer)))
	{
		return (filebuffer);
	}
	return (NULL);
}

STRPTR GetFile(void)
{
	UBYTE *pathbuffer;
	struct FileRequester *req;
	STRPTR 		 retval = NULL;

	AslBase = OpenLibrary("asl.library", 39);
	if (AslBase)
	{
		UBYTE *filepart;
		ULONG len;

		filepart = FilePart(filenamebuffer);
		stccpy(filebuffer, filepart, MAXPATH);

		len = filepart - filenamebuffer;
		pathbuffer = AllocMem(len + 1, MEMF_ANY);
		if (pathbuffer)
		{
			memcpy(pathbuffer, filenamebuffer, len);
			pathbuffer[len] = '\0';

			req = AllocAslRequestTags(ASL_FileRequest, ASLFR_TitleText    , (IPTR)MSG(MSG_ASL_OPEN_TITLE),
			                          ASLFR_DoPatterns   , TRUE			     ,
			                          ASLFR_InitialFile  , (IPTR)filebuffer	     ,
			                          ASLFR_InitialDrawer, (IPTR)pathbuffer	     ,
			                          TAG_DONE);
			if (req)
			{
				if (AslRequest(req, NULL))
				{
					stccpy(filebuffer, req->fr_Drawer, MAXPATH);
					AddPart(filebuffer, req->fr_File, MAXPATH-1);

					retval = filebuffer;

				} /* if (AslRequest(req, NULL) */

				FreeAslRequest(req);

			} /* if (req) */

			FreeMem(pathbuffer, len + 1);

		} /* if (pathbuffer) */

		CloseLibrary(AslBase);

	} /* if (AslBase) */

	return retval;
}

/*********************************************************************************************/

static struct Window	*aboutwindow;

void OpenAbout(void)
{
	struct EasyStruct   es;

	if (aboutwindow)
	{
		return;
	}

	es.es_StructSize   = sizeof(es);
	es.es_Flags        = 0;
	es.es_Title        = MSG(MSG_ABOUT_TITLE);
	es.es_TextFormat   = MSG(MSG_ABOUT);
	es.es_GadgetFormat = MSG(MSG_OK);

	aboutwindow = BuildEasyRequest(win, &es, NULL, VERSION,
	            REVISION,
	            (LONG) DATE,
	            (LONG) "2003-2004",
	            (LONG) "AROS",
				(LONG) "2003-" __COPYRIGHTYEAR__,
				(LONG) "MorphOS Team");

	if (aboutwindow == (APTR) 1)
	{
		aboutwindow = NULL;
	}
}

void CloseAbout(void)
{
	if (aboutwindow)
	{
		FreeSysRequest(aboutwindow);
		aboutwindow = NULL;
	}
}

ULONG GetAboutMask(void)
{
	ULONG mask = 0;

	if (aboutwindow)
	{
		mask = 1UL << aboutwindow->UserPort->mp_SigBit;
	}

	return mask;
}

void ProcessAbout(void)
{
	if (aboutwindow)
	{

		if (SysReqHandler(aboutwindow, NULL, FALSE) != -2)
		{
			CloseAbout();
		}
	}
}

